@@ -5,7 +5,7 @@ use crate::nixpacks::{
     app,
     environment::Environment,
     images::DEFAULT_BASE_IMAGE,
-    nix::{create_nix_expressions_for_phases, nix_file_names_for_phases},
+    nix::{create_nix_expressions_for_phases, nix_file_names_for_phases, setup_files_for_phases},
     plan::{
         phase::{Phase, StartPhase},
         BuildPlan,
@@ -105,6 +105,9 @@ impl DockerfileGenerator for BuildPlan {
     ) -> Result<String> {
         let plan = self;
 
+        let setup_files = setup_files_for_phases(&plan.phases.clone().unwrap_or_default());
+        let setup_copy_cmds = utils::get_copy_commands(&setup_files, APP_DIR).join("\n");
+
         let nix_file_names = nix_file_names_for_phases(&plan.phases.clone().unwrap_or_default());
 
         let mut nix_install_cmds: Vec<String> = Vec::new();
@@ -161,7 +164,7 @@ impl DockerfileGenerator for BuildPlan {
             let rel_assets_slash_path = rel_assets_path
                 .to_slash()
                 .context("Failed to convert nix file path to slash path.")?;
-            format!("COPY {} {}", rel_assets_slash_path, app::ASSETS_DIR)
+            format!("COPY {rel_assets_slash_path} {}", app::ASSETS_DIR)
         };
 
         let phases = plan.get_sorted_phases()?;
@@ -198,6 +201,7 @@ impl DockerfileGenerator for BuildPlan {
             ENTRYPOINT [\"/bin/bash\", \"-l\", \"-c\"]
             WORKDIR {APP_DIR}
 
+            {setup_copy_cmds}
             {nix_install_cmds}
             {apt_pkgs_str}
             {assets_copy_cmd}
@@ -209,6 +213,7 @@ impl DockerfileGenerator for BuildPlan {
         ", 
         base_image=base_image,
         APP_DIR=APP_DIR,
+        setup_copy_cmds=setup_copy_cmds,
         nix_install_cmds=nix_install_cmds,
         apt_pkgs_str=apt_pkgs_str,
         assets_copy_cmd=assets_copy_cmd,
@@ -259,11 +264,11 @@ impl BuildPlan {
                     let path = Path::new(&static_assets_path).join(name);
                     let parent = path.parent().unwrap();
                     fs::create_dir_all(parent)
-                        .context(format!("Creating parent directory for {}", name))?;
+                        .context(format!("Creating parent directory for {name}"))?;
                     let mut file =
-                        File::create(path).context(format!("Creating asset file for {}", name))?;
+                        File::create(path).context(format!("Creating asset file for {name}"))?;
                     file.write_all(content.as_bytes())
-                        .context(format!("Writing asset {}", name))?;
+                        .context(format!("Writing asset {name}"))?;
                 }
             }
         }
@@ -355,7 +360,7 @@ impl DockerfileGenerator for Phase {
         let (build_path, run_path) = if let Some(paths) = &phase.paths {
             let joined_paths = paths.join(":");
             (
-                format!("ENV PATH {}:$PATH", joined_paths),
+                format!("ENV PATH {joined_paths}:$PATH"),
                 format!(
                     "RUN printf '\\nPATH={}:$PATH' >> /root/.profile",
                     joined_paths
@@ -393,18 +398,18 @@ impl DockerfileGenerator for Phase {
             ]
             .concat()
             .iter()
-            .map(|s| format!("RUN {}", s))
+            .map(|s| format!("RUN {s}"))
             .collect::<Vec<_>>()
             .join("\n");
 
-            format!("{}\n{}", cache_copy_in_command, run_commands)
+            format!("{cache_copy_in_command}\n{run_commands}")
         } else {
             phase
                 .cmds
                 .clone()
                 .unwrap_or_default()
                 .iter()
-                .map(|s| format!("RUN {} {}", cache_mount, s))
+                .map(|s| format!("RUN {cache_mount} {s}"))
                 .collect::<Vec<_>>()
                 .join("\n")
         };
